summaryrefslogtreecommitdiff
path: root/thunar-volman/tvm-block-device.c
diff options
context:
space:
mode:
Diffstat (limited to 'thunar-volman/tvm-block-device.c')
-rw-r--r--thunar-volman/tvm-block-device.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/thunar-volman/tvm-block-device.c b/thunar-volman/tvm-block-device.c
index 475fd03..bba3b5e 100644
--- a/thunar-volman/tvm-block-device.c
+++ b/thunar-volman/tvm-block-device.c
@@ -572,8 +572,8 @@ tvm_block_device_autobrowse (TvmContext *context,
autobrowse = xfconf_channel_get_bool (context->channel, "/autobrowse/enabled", FALSE);
if (autobrowse)
{
- /* try to open the mount point in thunar */
- result = tvm_run_command (context, mount, "Thunar %m", &err);
+ /* try to open the mount point in the default File Manager */
+ result = tvm_run_command (context, mount, "exo-open --launch FileManager %m", &err);
}
/* forward errors to the caller */